@@ -6,6 +6,8 @@ multiple file uploads client side should result in multiple calls to the upload
 chain.
 """
 
+import os
+
 import flask
 from manhattan.assets.transforms.images import Fit, Output
 from manhattan.assets.backends import exceptions
@@ -55,10 +57,53 @@ def store_temporary_asset(state):
             or not flask.request.files['file'].filename:
         return utils.json_fail('No file sent')
 
-    # Attempt to store the file
+    # Apply the whitelist to
     file = flask.request.files['file']
-    asset_mgr = flask.current_app.asset_mgr
 
+    if state.ext_whitelist is None:
+        state.ext_whitelist = [
+            '.7z',
+            '.csv',
+            '.docx',
+            '.eml',
+            '.gif',
+            '.jpeg',
+            '.jpg',
+            '.key',
+            '.keynote',
+            '.md',
+            '.mp3',
+            '.msg',
+            '.odf',
+            '.ods',
+            '.odt',
+            '.ogg',
+            '.pages',
+            '.pdf',
+            '.png',
+            '.ppt',
+            '.pptx',
+            '.rar',
+            '.rtf',
+            '.svg',
+            '.tif',
+            '.tiff',
+            '.txt',
+            '.webp',
+            '.xls',
+            '.xlsx',
+            '.zip'
+        ]
+
+    if len(state.ext_whitelist):
+
+        filename, ext = os.path.splitext(file.filename)
+
+        if ext.lower() not in state.ext_whitelist:
+            return utils.json_fail('Not a supported file type.')
+
+    # Attempt to store the file
+    asset_mgr = flask.current_app.asset_mgr
     asset_name = state.asset_name
 
     if callable(asset_name):
